@@ -4,9 +4,10 @@ from typing import Callable
 
 import dill as pickle
 import numpy as np
-import pandas as pd
 
+from pandas_ml_common import Typing
 from pandas_ml_utils.ml.data.extraction import FeaturesAndLabels
+from pandas_ml_utils.ml.data.splitting.sampeling import Sampler
 from pandas_ml_utils.ml.summary import Summary
 
 
@@ -37,7 +38,7 @@ class Model(object):
 
     def __init__(self,
                  features_and_labels: FeaturesAndLabels,
-                 summary_provider: Callable[[pd.DataFrame], Summary] = Summary,
+                 summary_provider: Callable[[Typing.PatchedDataFrame], Summary] = Summary,
                  **kwargs):
         """
         All implementations of `Model` need to pass two arguments to `super().__init()__`.
@@ -67,9 +68,6 @@ class Model(object):
     def validation_indices(self):
         return self._validation_indices
 
-    def plot_loss(self):
-        pass
-
     def __getitem__(self, item):
         """
         returns arguments which are stored in the kwargs filed. By providing a tuple, a default in case of missing
@@ -93,12 +91,32 @@ class Model(object):
 
         print(f"saved model to: {os.path.abspath(filename)}")
 
-    def fit(self,
-            x: np.ndarray, y: np.ndarray,
-            x_val: np.ndarray, y_val: np.ndarray,
-            sample_weight_train: np.ndarray, sample_weight_test: np.ndarray) -> float:
+    def plot_loss(self):
         """
-        function called to fit the model
+        implement this function to plot a diagram of the training and validation losses
+        :return:
+        """
+        pass
+
+    def fit(self, sampler: Sampler, **kwargs) -> float:
+        """
+        draws folds from the data generator as long as it yields new data and fits the model to one fold
+
+        :param sampler: a data generating process class:`pandas_ml_utils.ml.data.splitting.sampeling.Sampler`
+        :return: returns the average loss over oll folds
+        """
+
+        # sample: train[features, labels, target, weights], test[features, labels, target, weights]
+        losses = [self.fit_fold(s[0][0], s[0][1], s[1][0], s[1][1], s[0][3], s[1][3], **kwargs) for s in sampler.sample()]
+        return np.array(losses).mean()
+
+    def fit_fold(self,
+                 x: np.ndarray, y: np.ndarray,
+                 x_val: np.ndarray, y_val: np.ndarray,
+                 sample_weight_train: np.ndarray, sample_weight_test: np.ndarray,
+                 **kwargs) -> float:
+        """
+        function called to fit the model to one fold of the data generator (i.e. k-folds)
         :param x: x
         :param y: y
         :param x_val: x validation
@@ -109,9 +127,19 @@ class Model(object):
         """
         pass
 
-    def predict(self, x: np.ndarray) -> np.ndarray:
+    def predict(self, sampler: Sampler, **kwargs) -> np.ndarray:
         """
-        prediction of the model for each target
+        predict as many samples as we can sample from the sampler
+
+        :param sampler:
+        :return:
+        """
+        # make shape (rows, samples, ...)
+        return np.array([self.predict_sample(t[0]) for (t, _) in sampler.sample()]).swapaxes(0, 1)
+
+    def predict_sample(self, x: np.ndarray, **kwargs) -> np.ndarray:
+        """
+        prediction of the model for each sample and target
 
         :param x: x
         :return: prediction of the model for each target
